@@ -45,13 +45,13 @@ class H3Manager:
 
         return info
 
-    def start(self, hmmfile: HMMFile, force=False):
+    def start(self, hmmfile: HMMFile, port: int = 0, force=False):
         master_image = self.fetch_image(H3MASTER_IMAGE)
         worker_image = self.fetch_image(H3WORKER_IMAGE)
         pod = H3Pod(hmmfile, master_image, worker_image)
         if force:
             self.stop(pod.namespace)
-        pod.start(self._podman)
+        pod.start(self._podman, port)
         return pod
 
     def stop(self, ns: Namespace):
